![Metaflow_Logo_Horizontal_FullColor_Ribbon_Dark_RGB](https://user-images.githubusercontent.com/763451/89453116-96a57e00-d713-11ea-9fa6-82b29d4d6eff.png)

# Aero Metaflow

This library contains a fork of Metaflow (http://metaflow.org/) which is used by Aero to orchestrate Jobs.

While this library has been heavily edited in parts, credit still goes to the amazing work the Metaflow team have done.